"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.evaluatePath = evaluatePath;
exports.objectExpressionToObject = objectExpressionToObject;
exports.jsxAttributesToObject = jsxAttributesToObject;

var _extends4 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var R = _interopRequireWildcard(require("ramda"));

var _printIcuMessage = _interopRequireDefault(require("babel-plugin-react-intl/dist/print-icu-message"));

// import printAST from 'ast-pretty-print';

/**
 * Evaluate JSXExpression
 * ref: https://github.com/yahoo/babel-plugin-react-intl/blob/6d364b01554f80433067202f342d6b516b03daaa/src/index.js#L31-L40
 */
function evaluatePath(path) {
  var evaluated = path.evaluate();

  if (evaluated.confident) {
    return evaluated.value;
  }

  throw path.buildCodeFrameError('[React Intl] Messages must be statically evaluate-able for extraction.');
}

function objectExpressionToObject(objectExpression) {
  return objectExpression.get('properties').reduce(function (acc, property) {
    var _extends2;

    var name = property.get('key').node.name;
    var value = property.get('value').node.value; // Note: expression and templateLiteral

    if (property.get('value').isTemplateLiteral() || property.get('value').isBinaryExpression()) {
      value = R.pipe(evaluatePath, R.ifElse(R.is(String), _printIcuMessage["default"], R.identity))(property.get('value'));
    }

    return (0, _extends4["default"])({}, acc, (_extends2 = {}, _extends2[name] = value, _extends2));
  }, {});
}

function jsxAttributesToObject(jsxAttributes) {
  return jsxAttributes.reduce(function (acc, attribute) {
    var _extends3;

    var name = attribute.get('name').node.name;
    var value = attribute.get('value').node.value; // Note: expression and templateLiteral

    if (attribute.get('value').isJSXExpressionContainer()) {
      value = R.pipe(evaluatePath, R.ifElse(R.is(String), _printIcuMessage["default"], R.identity))(attribute.get('value.expression'));
    }

    return (0, _extends4["default"])({}, acc, (_extends3 = {}, _extends3[name] = value, _extends3));
  }, {});
}